package
Version:
v0.0.0-...-537ddf9
Opens a new window with list of versions in this module.
Published: Oct 1, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func CopySSHKey(publicKeyPath, serverIP, username, password string) error
-
func ExecuteCommand(serverIP, username, password, privateKeyPath, command string) (string, error)
-
func InteractiveSession(serverIP, privateKeyPath, username string) error
func CopySSHKey(publicKeyPath, serverIP, username, password string) error
func ExecuteCommand(serverIP, username, password, privateKeyPath, command string) (string, error)
func InteractiveSession(serverIP, privateKeyPath, username string) error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.